#!/usr/bin/python

CSV_DATA = 'packages-files-difference-average.csv'
TEX_OUTPUT = 'changes-pctg-table.tex'

import sys
sys.path.append('../debsources/python')

import csv
import string

import statistics
from debsources_data import get_suites, correct_suite_name

suites = [ s for s, d in get_suites() if s not in ['jessie', 'sid'] ]
all_suites = [ s for s, d in get_suites() ]
suites = suites[1:]	# drop 'hamm', as it has no previous suite in dataset
stats = statistics.load_metadata_cache('stats.data')

filediff_pct = {}
with open(CSV_DATA) as csvfile:
    csvreader = csv.reader(csvfile)
    for from_to, pctg in csvreader:
        if from_to == 'from_to':
            continue
        filediff_pct[from_to] = float(pctg)

def common_packages(from_suite, to_suite):
    changes_file = 'changes/%s-to-%s.data' % (from_suite, to_suite)
    with open(changes_file) as changes:
        for line in changes:
            k, v = line.split()
            if k == 'common':
                return int(v)

def modified_pctg(from_suite, to_suite):
    global filediff_pct
    return filediff_pct[from_suite + '-' + to_suite]

# header
print r'\begin{tabular}{l|%s}' % ('r|' * 7 + 'r')
print r'& \multicolumn{8}{l}{\textbf{\emph{from previous suite to}}}\\\cline{1-9}'
for suite in suites[:-1]:
    print r'& \multicolumn{1}{c|}{\textbf{%s}}' % correct_suite_name(suite),
print r'& \multicolumn{1}{c}{\textbf{%s}}' % correct_suite_name(suites[-1]),
print r'\\\hline'

# row: modified packages
cells = [r'\textbf{modified pkgs}']
for to_suite in suites:
    from_suite = all_suites[all_suites.index(to_suite) - 1]
    src_pkgs = stats['debian_%s.source_packages' % to_suite]
    common_pkgs = common_packages(from_suite, to_suite)
    modif_pkgs = src_pkgs - common_pkgs
    cell = r'%dm' % modif_pkgs
    cells.append(cell)
print string.join(cells, ' & '),
print r'\\'

# row: modified files %
cells = [r'\textbf{changed files per pkg}']
for to_suite in suites:
    from_suite = all_suites[all_suites.index(to_suite) - 1]
    modif_pctg = modified_pctg(from_suite, to_suite)
    cell = r'%.1f\%%' % modif_pctg
    cells.append(cell)
print string.join(cells, ' & '),
print r'\\'

# footer
print r'\end{tabular}'
