#!/usr/bin/python

import sys
sys.path.append('../debsources/python')

import glob
import os

from debsources_data import get_suites, correct_suite_name
SUITES = map(lambda (suite, _date): suite, get_suites())

def load_changes(fname):
    data = {}
    for f in open(fname):
        k,v = f.split()
        data[k] = int(v)
    return data

def print_changes_tbl(changes):
    columns = len(SUITES) # - 1 + 1
    rows = len(SUITES) # - 1 + 1
    col_titles = SUITES[1:]
    print r'\begin{tabular}{l%s}' % ('|R{8.8mm}' * (columns - 1))
    print r' & \multicolumn{%d}{l}{\textbf{\emph{to}}} \\\cline{2-11}' % (columns - 1)
    # heading
    print r'\multicolumn{1}{r|}{\textbf{\emph{from}}}',
    for suite in col_titles[:-1]:
        print r' & \multicolumn{1}{c|}{\textbf{%s}}' % correct_suite_name(suite),
    print r' & \multicolumn{1}{c}{\textbf{%s}} \\' % correct_suite_name(col_titles[-1])
    # data
    for from_suite in SUITES[:-1]:
        print r'\hline'
        print r'\textbf{%s}' % correct_suite_name(from_suite),
        filled_cols = 1
        for to_suite in col_titles:
            try:
                data = changes[from_suite][to_suite]
                if from_suite != to_suite:
                    cell = r'%dc\newline %du' % (data['common'], data['unchanged'])
                    # cell += r'\newline %dn\newline %dr' % (data['new'], data['removed'])
                else:
                    cell = ''
            except KeyError:
                cell = ''
            print '& %s' % cell,
            filled_cols += 1
        print r' &' * (len(col_titles) - filled_cols),
        print r'\\'
    print '\end{tabular}'

changes = {}

for f in glob.glob('changes/*-to-*.data'):
    base = os.path.splitext(os.path.basename(f))[0]	# e.g. squeeze-to-sid
    _base = base.split('-')
    from_suite, to_suite = _base[0], _base[-1]
    if not changes.has_key(from_suite):
        changes[from_suite] = {}
    changes[from_suite][to_suite] = load_changes(f)

print_changes_tbl(changes)
