#!/bin/bash

DBNAME="$1"
if [ -z "$DBNAME" ] ; then
    echo "Usage: $0 DBNAME"
    exit 1
fi
PSQL="psql --tuples-only --quiet --no-align $DBNAME"

SUITES=$(cut -f 1 suites.data)

for from_suite in $SUITES ; do
    in_range='no'
    for to_suite in $SUITES ; do
	if [ "$from_suite" = "$to_suite" ] ; then
	    in_range="yes"
	    # continue
	fi
	if [ "$in_range" = "no" ] ; then
	    continue
	fi
	echo "${from_suite} -> ${to_suite}"
	unchanged=$($PSQL <<EOF
SELECT COUNT(*) FROM
((SELECT package_names.name, upstream_version(packages.version)
   FROM suites, packages, package_names
   WHERE suites.package_id = packages.id
   AND packages.name_id = package_names.id
   AND suites.suite = '$from_suite')
  INTERSECT
  (SELECT package_names.name, upstream_version(packages.version)
   FROM suites, packages, package_names
   WHERE suites.package_id = packages.id
   AND packages.name_id = package_names.id
   AND suites.suite = '$to_suite')) S;
EOF
)
	common=$($PSQL <<EOF
SELECT COUNT(*) FROM
((SELECT package_names.name
   FROM suites, packages, package_names
   WHERE suites.package_id = packages.id
   AND packages.name_id = package_names.id
   AND suites.suite = '$from_suite')
  INTERSECT
  (SELECT package_names.name
   FROM suites, packages, package_names
   WHERE suites.package_id = packages.id
   AND packages.name_id = package_names.id
   AND suites.suite = '$to_suite')) S;
EOF
)
	new=$($PSQL <<EOF
SELECT COUNT(*) FROM
((SELECT package_names.name
   FROM suites, packages, package_names
   WHERE suites.package_id = packages.id
   AND packages.name_id = package_names.id
   AND suites.suite = '$to_suite')
  EXCEPT
  (SELECT package_names.name
   FROM suites, packages, package_names
   WHERE suites.package_id = packages.id
   AND packages.name_id = package_names.id
   AND suites.suite = '$from_suite')) S;
EOF
)
	removed=$($PSQL <<EOF
SELECT COUNT(*) FROM
((SELECT package_names.name
   FROM suites, packages, package_names
   WHERE suites.package_id = packages.id
   AND packages.name_id = package_names.id
   AND suites.suite = '$from_suite')
  EXCEPT
  (SELECT package_names.name
   FROM suites, packages, package_names
   WHERE suites.package_id = packages.id
   AND packages.name_id = package_names.id
   AND suites.suite = '$to_suite')) S;
EOF
)
	changes="changes/${from_suite}-to-${to_suite}.data"
	> $changes
	echo -e "common\t${common}" >> $changes
	echo -e "unchanged\t${unchanged}" >> $changes
	echo -e "new\t${new}" >> $changes
	echo -e "removed\t${removed}" >> $changes
    done
done
