#!/usr/bin/python

CSV_FILE = "packages-suites.csv"
RESULT_FILE = "package-average-life.data"

import sys
sys.path.append('../debsources/python')

import csv
import datetime
from consts import DEBIAN_RELEASES
from debsources_data import next_release_date

DEBIAN_RELEASES["jessie"] = {'version': 8,
                             'date': next_release_date()}
# only used to compare dates, not a real value:
DEBIAN_RELEASES["sid"] = {'version': 9,
                             'date': datetime.date(2017, 1, 1)}

RLS = sorted(DEBIAN_RELEASES,
             cmp=lambda x, y:
                 2*(DEBIAN_RELEASES[x]["date"] > DEBIAN_RELEASES[y]["date"])-1)

class P_life(object):
    def __init__(self, suite):
        self.first = suite
        self.last = suite
    
    def _date(self, suite):
        return DEBIAN_RELEASES[suite]["date"]
    
    def update(self, suite):
        if self._date(suite) < self._date(self.first):
            self.first = suite
        if self._date(suite) > self._date(self.last):
            self.last = suite
    
    def life(self):
        if self.first in ("jessie", "sid", "experimental"):
            return None
        if self.last in ("jessie", "sid", "experimental"):
            return None
        
        # end of package = begin of next release
        try:
            end = self._date(RLS[RLS.index(self.last)+1])
        except ValueError, KeyError: # e.g. *-backports
            return None
        return (end - self._date(self.first)).days
    
    def __repr__(self):
        return self.first + ":" + self.last + ":" + str(self.life())


def compute_average_life(csv_file):
    p = dict()
    with open(csv_file) as f:
        reader = csv.reader(f)
        reader.next() # we skip the labels line
        for line in reader:
            try:
                p[line[0] + " " + line[1]].update(line[2])
            except: # this package is not in our data structure yet
                p[line[0] + " " + line[1]] = P_life(line[2])
    
    lifes = filter(lambda x: x is not None,
                   [x.life() for x in p.values()])
    avg = float(sum(lifes)) / len(lifes)
    
    return avg


if __name__ == "__main__":
    with open(RESULT_FILE, "w") as f:
        f.write(str(compute_average_life(CSV_FILE)))
