-- computes, for each package:
-- the number of files in a specified version, the number of files in a more
-- recent version, and the number of common files between them

SELECT package_names.name, P1.version, S1.suite, P2.version, S2.suite,
 (SELECT COUNT(*)
   FROM checksums
   WHERE P1.id = checksums.package_id) AS count1,
 (SELECT COUNT(*)
   FROM checksums
   WHERE P2.id = checksums.package_id) AS count2,
 (SELECT COUNT(*) FROM (
  (SELECT checksums.sha256
   FROM checksums
   WHERE P1.id = checksums.package_id)
  INTERSECT
  (SELECT checksums.sha256
   FROM checksums
   WHERE P2.id = checksums.package_id)
 ) AS foo) AS inter
FROM package_names, packages P1, packages P2, suites S1, suites S2, suites_info SI1, suites_info SI2
WHERE P1.name_id = package_names.id
  AND P1.name_id = P2.name_id
  AND S1.suite = SI1.name
  AND S2.suite = SI2.name
  AND SI1.release_date < SI2.release_date
  AND upstream_version(P1.version) != upstream_version(P2.version)
  AND S1.package_id = P1.id
  AND S2.package_id = P2.id
ORDER BY package_names.name ;
