#!/usr/bin/python

CSV_FILE = "packages-suites.csv"

import sys
sys.path.append('../debsources/python')

import csv
import sqlalchemy
from sqlalchemy.sql.expression import func
from models import PackageName, Package, Suite

def packages_suites(session):
    data = (session.query(PackageName.name,
                          func.upstream_version(Package.version),
                          Suite.suite)
            .filter(PackageName.id == Package.name_id)
            .filter(Package.id == Suite.package_id)
            .distinct()
            .all()
            )
    
    return data

def csv_output(csv_file, data):
    with open(csv_file, "w") as f:
        w = csv.writer(f, quoting=csv.QUOTE_ALL)
        w.writerow(["package", "version", "suite"])
        for record in data:
            w.writerow(record)

if __name__ == "__main__":
    try:
        dburi = sys.argv[1]
    except:
        print("usage: packages-suites.py database_uri")
        sys.exit(1)
    
    db = sqlalchemy.create_engine(dburi)
    Session = sqlalchemy.orm.sessionmaker()
    session = Session(bind=db)
    
    data = packages_suites(session)
    csv_output(CSV_FILE, data)
