#!/usr/bin/python

FIGS_DIR = "./charts"
CHART_FILE = 'sloc-freq-%s.png'

import sys

import matplotlib
matplotlib.use('Agg')
import matplotlib.pyplot as plt
from matplotlib.ticker import ScalarFormatter

def format_scientific_axis(obj):
    formatter = ScalarFormatter()
    formatter.set_scientific(True)
    formatter.set_powerlimits((-3,3))
    obj.xaxis.set_major_formatter(formatter)

def read_freq(fname):
    freqs = []
    with open(fname) as data:
        for line in data:
            pkgid, sloc = line.split()
            freqs.append(int(sloc))
    return freqs

def plot(freqs, fname):
    matplotlib.rc('font', size=30)
    plt.figure()
    fig, ax = plt.subplots(1)
    format_scientific_axis(ax)
    plt.yscale('log', nonposy='clip')
    plt.hist(freqs, bins=250)
    plt.subplots_adjust(bottom=0.2)
    plt.savefig(fname)
    plt.close()

plot(read_freq(sys.argv[1]), fname=sys.argv[2])
